/***************************/
/***** Error Constants *****/
/***************************/
/* Documentation: Specifies the error detected by the chart. */

/* Documentation: Invalid index found in variant */
const int ocErrorInvalidIndex = 0;

/* Documentation: Property is read-only and cannot be modified */
const int ocErrorReadOnly = 1;

/* Documentation: Numeric value is out of range */
const int ocErrorOutOfRange = 2;

/* Documentation: Invalid enumerated value for property */
const int ocErrorInvalidEnum = 3;

/* Documentation: Invalid value for property */
const int ocErrorInvalidValue = 4;

/* Documentation: Property does not exist for this instance of the object */
const int ocErrorNoSuchProperty = 5;

/* Documentation: Collection already contains a duplicate value */
const int ocErrorDuplicateValue = 6;

/* Documentation: Cannot find item in collection */
const int ocErrorNoSuchItem = 7;

/* Documentation: Cannot create object */
const int ocErrorCannotCreateObject = 8;

/* Documentation: Property set to wrong object type */
const int ocErrorTypeMismatch = 9;

/****************************/
/***** Adjust Constants *****/
/****************************/
/* Documentation: Specifies the alignment of multiple lines of text. */

/* Documentation: Aligned to left edge. */
const int oc2dAdjustLeft = 1;

/* Documentation: Aligned to right edge. */
const int oc2dAdjustRight = 2;

/* Documentation: Centered. */
const int oc2dAdjustCenter = 3;

/*********************************/
/***** Orientation Constants *****/
/*********************************/
/* Documentation: Specifies the orientation. */

/* Documentation: Vertical orientation. */
const int oc2dOrientVertical = 1;

/* Documentation: Horizontal orientation. */
const int oc2dOrientHorizontal = 2;

/****************************/
/***** Anchor Constants *****/
/****************************/
/* Documentation: Specifies the position of the object
   relative to the anchor position. */

/* Documentation: Above anchor position. */
const int oc2dAnchorNorth = 16;

/* Documentation: Below anchor position. */
const int oc2dAnchorSouth = 32;

/* Documentation: To right of anchor position. */
const int oc2dAnchorEast = 1;

/* Documentation: To left of anchor position. */
const int oc2dAnchorWest = 2;

/* Documentation: Above and to right of anchor position. */
const int oc2dAnchorNorthEast = 17;

/* Documentation: Above and to left of anchor position. */
const int oc2dAnchorNorthWest = 18;

/* Documentation: Below and to right of position. */
const int oc2dAnchorSouthEast = 33;

/* Documentation: Below and to left of position. */
const int oc2dAnchorSouthWest = 34;

/* Documentation: Center over anchor position (ChartLabel object only). */
const int oc2dAnchorCenter = 0;

/* Documentation: Automatically position the object (ChartLabel object only). */
const int oc2dAnchorAuto = 256;

/***************************************/
/***** Annotation Method Constants *****/
/***************************************/
/* Documentation: Specifies the annotation method. */

/* Documentation: Annotate using chart's X- or Y-values. */
const int oc2dAnnotateValues = 0;

/* Documentation: Annotate using Point-labels (X-axis only). */
const int oc2dAnnotatePointLabels = 1;

/* Documentation: Annotate using ValueLabels property. */
const int oc2dAnnotateValueLabels = 2;

/* Documentation: Annotate using Time-labels (X-axis only). */
const int oc2dAnnotateTimeLabels = 3;

/******************************************/
/***** Annotation Placement Constants *****/
/******************************************/
/* Documentation: Specifies the placement of the axis annotation and title. */

/* Documentation: Annotation placement automatically determined. */
const int oc2dAnnotateAuto = 0;

/* Documentation: Annotation along the origin. */
const int oc2dAnnotateOrigin = 1;

/* Documentation: Annotation along the axis minimum. */
Const int oc2dAnnotateMinimum = 2;

/* Documentation: Annotation along the axis maximum. */
const int oc2dAnnotateMaximum = 3;

/***********************************/
/***** Attach Method Constants *****/
/***********************************/
/* Documentation: Specifies how a chart label is attached to a chart. */

/* Documentation: Attach at specified pixel coordinate. */
const int oc2dAttachCoord = 0;

/* Documentation: Attach to specified data coordinates. */
const int oc2dAttachDataCoord = 1;

/* Documentation: Attach to specified data indices. */
const int oc2dAttachDataIndex = 2;

/* Documentation: Attach using data index for X coordinate,
   and data value for Y coordinate. */
const int oc2dAttachDataIndexDataY = 3;

/*****************************/
/***** Axis ID Constants *****/
/*****************************/
/* Documentation: Specifies a chart axis. */

/* Documentation: X-axis. */
const int oc2dAxisX = 0;

/* Documentation: Y-axis. */
const int oc2dAxisY = 1;

/* Documentation: Y2-axis (second Y-axis). */
const int oc2dAxisY2 = 2;

/*********************************/
/***** Border Type Constants *****/
/*********************************/
/* Documentation: Valid border styles. */

/* Documentation: Border None */
const int oc2dBorderNone = 0;

/* Documentation: Border 3D Out */
const int oc2dBorder3DOut = 1;

/* Documentation: Border 3D In */
const int oc2dBorder3DIn = 2;

/* Documentation: Border Shadow */
const int oc2dBorderShadow = 3;

/* Documentation: Border Plain */
const int oc2dBorderPlain = 4;

/* Documentation: Border Etched In */
const int oc2dBorderEtchedIn = 5;

/* Documentation: Border Etched Out */
const int oc2dBorderEtchedOut = 6;

/*********************************/
/***** Data Layout Constants *****/
/*********************************/
/* Documentation: Specifies the layout of the data to be graphed. */

/* Documentation: Array data. */
const int oc2dDataArray = 1;

/* Documentation: General data. */
const int oc2dDataGeneral = 2;

/**********************************/
/***** Fill Pattern Constants *****/
/**********************************/
/* Documentation: Valid fill patterns. */

/* Documentation: No Fill Pattern */
const int oc2dFillNone = 1;

/* Documentation: Solid Fill */
const int oc2dFillSolid = 2;

/* Documentation: 25% Fill */
Const int oc2dFill25Percent = 3;

/* Documentation: 50% Fill */
const int oc2dFill50Percent = 4;

/* Documentation: 75% Fill */
const int oc2dFill75Percent = 5;

/* Documentation: Horizontal Stripe */
const int oc2dFillHorizontalStripe = 6;

/* Documentation: Vertical Stripe */
const int oc2dFillVerticalStripe = 7;

/* Documentation: 45 Degree Stripe */
const int oc2dFill45DegreeStripe = 8;

/* Documentation: 135 Degree Stripe */
const int oc2dFill135DegreeStripe = 9;

/* Documentation: Diagonal Hatched */
const int oc2dFillDiagHatched = 10;

/* Documentation: Cross Hatched */
const int oc2dFillCrossHatched = 11;

/* Documentation: Backward Diagonal */
const int oc2dFillBackwardDiagonal = 12;

/* Documentation: Cross */
const int oc2dFillCross = 13;

/* Documentation: Diagonal Cross */
const int oc2dFillDiagonalCross = 14;

/* Documentation: Forward Diagonal */
const int oc2dFillForwardDiagonal = 15;

/* Documentation: Horizontal */
const int oc2dFillHorizontal = 16;

/* Documentation: Vertical */
const int oc2dFillVertical = 17;

/***************************/
/***** Focus Constants *****/
/***************************/
/* Documentation: Specifies how the nearest series and
   point value are determined. */

/* Documentation: Use X-axis to determine closest value. */
const int oc2dFocusX = 1;

/* Documentation: Use Y-axis to determine closest value. */
const int oc2dFocusY = 2;

/* Documentation: Use both axes to determine closest value. */
const int oc2dFocusXY = 3;

/**********************************/
/***** Line Pattern Constants *****/
/**********************************/
/* Documentation: Valid line patterns. */

/* Documentation: No Line Pattern */
const int oc2dLineNone = 1;

/* Documentation: Solid */
const int oc2dLineSolid = 2;

/* Documentation: Long Dash */
const int oc2dLineLongDash = 3;

/* Documentation: Dotted */
const int oc2dLineDotted = 4;

/* Documentation: Short Dash */
const int oc2dLineShortDash = 5;

/* Documentation: Long Short Long Dash */
const int oc2dLineLongShortLongDash = 6;

/* Documentation: Dash Dot */
const int oc2dLineDashDot = 7;

/***********************************/
/***** Marker Method Constants *****/
/***********************************/
/* Documentation: Specifies the marker positioning method used. */

/* Documentation: Specify position in data coordinates. */
const int oc2dMarkerDataCoord = 0;

/* Documentation: Specify position as an index into a data set. */
const int oc2dMarkerDataIndex = 1;

/********************************/
/***** Num Method Constants *****/
/********************************/
/* Documentation: Specifies the method used to calculate axis numbering. */

/* Documentation: Use current value of axis precision. */
const int oc2dNumPrecision = 0;

/* Documentation: Use rounded numbers (most significant digit is 1, 2 or 5). */
const int oc2dNumRound = 1;

/**************************************/
/***** Origin Placement Constants *****/
/**************************************/
/* Documentation: Specifies the location of the origin. */

/* Documentation: Origin location automatically determined. */
const int oc2dOriginAuto = 0;

/* Documentation: Origin at zero. */
const int oc2dOriginZero = 1;

/* Documentation: Origin at axis minimum. */
const int oc2dOriginMinimum = 2;

/* Documentation: Origin at axis maximum. */
const int oc2dOriginMaximum = 3;

/********************************/
/***** Sort Order Constants *****/
/********************************/
/* Documentation: Specifies the order in which pie slices should be displayed. */

/* Documentation: Ascending order. */
const int oc2dSortOrderAscending = 1;

/* Documentation: Descending order. */
const int oc2dSortOrderDescending = 2;

/* Documentation: Data Order. */
const int oc2dSortOrderNone = 3;

/*******************************/
/***** Threshold Constants *****/
/*******************************/
/* Documentation: Specifies the method used to determine which point
   values will be grouped into the "other" slice in pie charts. */

/* Documentation: Group all values whose individual percentage
   is less than ThresholdValue. */
const int oc2dThresholdSliceCutoff = 1;

/* Documentation: Group values whose total percentage is less
   than ThresholdValue. */
const int oc2dThresholdPercentile = 2;

/***************************/
/***** Shape Constants *****/
/***************************/
/* Documentation: Valid symbol shapes. */

/* Documentation: None */
const int oc2dShapeNone = 1;

/* Documentation: Dot */
const int oc2dShapeDot = 2;

/* Documentation: Box */
const int oc2dShapeBox = 3;

/* Documentation: Triangle */
const int oc2dShapeTriangle = 4;

/* Documentation: Diamond */
const int oc2dShapeDiamond = 5;

/* Documentation: Star */
const int oc2dShapeStar = 6;

/* Documentation: Vertical Line */
const int oc2dShapeVerticalLine = 7;

/* Documentation: Horizontal Line */
const int oc2dShapeHorizontalLine = 8;

/* Documentation: Cross */
const int oc2dShapeCross = 9;

/* Documentation: Circle */
const int oc2dShapeCircle = 10;

/* Documentation: Square */
const int oc2dShapeSquare = 11;

/****************************/
/***** Region Constants *****/
/****************************/
/* Documentation: Specifies a region of a chart. */

/* Documentation: Located in chart area. */
const int oc2dRegionInChartArea = -100;

/* Documentation: Located in legend. */
const int oc2dRegionInLegend = -99;

/* Documentation: Located in header. */
const int oc2dRegionInHeader = -98;

/* Documentation: Located in footer. */
const int oc2dRegionInFooter = -97;

/* Documentation: No particular region. */
const int oc2dRegionNone = -96;

/******************************/
/***** Rotation Constants *****/
/******************************/
/* Documentation: Specifies an angle of rotation
   (in counterclockwise degrees). */

/* Documentation: No rotation. */
const int oc2dRotateNone = 1;

/* Documentation: Rotate 90 degrees. */
const int oc2dRotate90Degrees = 2;

/* Documentation: Rotate 270 degrees. */
const int oc2dRotate270Degrees = 3;

/*******************************/
/***** Time Unit Constants *****/
/*******************************/
/* Documentation: Specifies the time unit to use in a time-axis. */

/* Documentation: Seconds */
const int oc2dTimeSeconds = 1;

/* Documentation: Minutes */
const int oc2dTimeMinutes = 2;

/* Documentation: Hours */
const int oc2dTimeHours = 3;

/* Documentation: Days */
const int oc2dTimeDays = 4;

/* Documentation: Weeks */
const int oc2dTimeWeeks = 5;

/* Documentation: Months */
const int oc2dTimeMonths = 6;

/* Documentation: Years */
const int oc2dTimeYears = 7;

/********************************/
/***** Chart Type Constants *****/
/********************************/
/* Documentation: Specifies the chart display type. */

/* Documentation: Line chart. */
const int oc2dTypePlot = 1;

/* Documentation: Bar chart. */
const int oc2dTypeBar = 2;

/* Documentation: Pie chart. */
const int oc2dTypePie = 3;

/* Documentation: Stacking bar chart. */
const int oc2dTypeStackingBar = 4;

/* Documentation: Area chart. */
const int oc2dTypeArea = 5;

/****************************/
/***** Action Constants *****/
/****************************/
/* Documentation: Specifies a user action. */

/* Documentation: No action. */
const int oc2dActionNone = 0;

/* Documentation: Start a user interaction. */
const int oc2dActionModifyStart = 1;

/* Documentation: Notify application that user interaction has ended. */
const int oc2dActionModifyEnd = 2;

/* Documentation: Rotate the chart. */
const int oc2dActionRotate = 3;

/* Documentation: Scale the chart. */
const int oc2dActionScale = 4;

/* Documentation: Translate the chart. */
const int oc2dActionTranslate = 5;

/* Documentation: Start zoom. */
const int oc2dActionZoomStart = 6;

/* Documentation: Update the zoom area selection rubberband. */
const int oc2dActionZoomUpdate = 7;

/* Documentation: Zoom into chart at the area selected by the rubberband. */
const int oc2dActionZoomEnd = 8;

/* Documentation: Cancel zoom in progress. */
const int oc2dActionZoomCancel = 9;

/* Documentation: Restore all scaling and translations to default. */
const int oc2dActionReset = 10;

/* Documentation: Display property page. */
const int oc2dActionProperties = 11;

/****************************/
/***** Format Constants *****/
/****************************/
/* Documentation: Specifies the format to use when printing. */

/* Documentation: Bitmap (.BMP). */
const int oc2dFormatBitmap = 1;

/* Documentation: Metafile (.WMF). */
const int oc2dFormatMetafile = 2;

/* Documentation: Enhanced metafile (.EMF). */
const int oc2dFormatEnhMetafile = 3;

/***************************/
/***** Scale Constants *****/
/***************************/
/* Documentation: Specifies the scaling to use when printing. */

/* Documentation: Same size as actual chart. */
const int oc2dScaleNone = 1;

/* Documentation: Scale to specified width, preserving aspect ratio. */
const int oc2dScaleToWidth = 2;

/* Documentation: Scale to specified height, preserving aspect ratio. */
const int oc2dScaleToHeight = 3;

/* Documentation: Scale to existing window (minimum of height and width),
   preserving aspect ratio. */
const int oc2dScaleToFit = 4;

/* Documentation: Enlarge to size of page. */
const int oc2dScaleToMax = 5;

