/***************************/
/***** Error Constants *****/
/***************************/
/* Documentation: Specifies the error detected by the chart. */

/* Documentation: Invalid index found in variant */
const int ocErrorInvalidIndex = 0;

/* Documentation: Property is read-only and cannot be modified */
const int ocErrorReadOnly = 1;

/* Documentation: Numeric value is out of range */
const int ocErrorOutOfRange = 2;

/* Documentation: Invalid enumerated value for property */
const int ocErrorInvalidEnum = 3;

/* Documentation: Invalid value for property */
const int ocErrorInvalidValue = 4;

/* Documentation: Property does not exist for this instance of the object */
const int ocErrorNoSuchProperty = 5;

/* Documentation: Collection already contains a duplicate value */
const int ocErrorDuplicateValue = 6;

/* Documentation: Cannot find item in collection */
const int ocErrorNoSuchItem = 7;

/* Documentation: Cannot create object */
const int ocErrorCannotCreateObject = 8;

/* Documentation: Property set to wrong object type */
const int ocErrorTypeMismatch = 9;

/****************************/
/***** Adjust Constants *****/
/****************************/
/* Documentation: Specifies the alignment of multiple lines
   of text in a header or footer. */

/* Documentation: Aligned to left edge. */
const int oc3dAdjustLeft = 1;

/* Documentation: Aligned to right edge. */
const int oc3dAdjustRight = 2;

/* Documentation: Centered. */
const int oc3dAdjustCenter = 3;

/*********************************/
/***** Orientation Constants *****/
/*********************************/
/* Documentation: Specifies the orientation. */

/* Documentation: Vertical orientation. */
const int oc3dOrientVertical = 1;

/* Documentation: Horizontal orientation. */
const int oc3dOrientHorizontal = 2;

/****************************/
/***** Anchor Constants *****/
/****************************/
/* Documentation: Specifies the position of the object
   relative to the anchor position. */

/* Documentation: Above anchor position. */
const int oc3dAnchorNorth = 16;

/* Documentation: Below anchor position. */
const int oc3dAnchorSouth = 32;

/* Documentation: To right of anchor position. */
const int oc3dAnchorEast = 1;

/* Documentation: To left of anchor position. */
const int oc3dAnchorWest = 2;

/* Documentation: Above and to right of anchor position. */
const int oc3dAnchorNorthEast = 17;

/* Documentation: Above and to left of anchor position. */
const int oc3dAnchorNorthWest = 18;

/* Documentation: Below and to right of position. */
const int oc3dAnchorSouthEast = 33;

/* Documentation: Below and to left of position. */
const int oc3dAnchorSouthWest = 34;

/***************************************/
/***** Annotation Method Constants *****/
/***************************************/
/* Documentation: Specifies the annotation method. */

/* Documentation: Annotate using chart's data values. */
const int oc3dAnnotateValues = 1;

/* Documentation: Annotate using data labels. */
const int oc3dAnnotateDataLabels = 2;

/* Documentation: Annotate using ValueLabels property. */
const int oc3dAnnotateValueLabels = 3;

/***********************************/
/***** Attach Method Constants *****/
/***********************************/
/* Documentation: Specifies how a chart label is attached to a chart. */

/* Documentation: Attach to a grid index. */
const int oc3dAttachDataIndex = 0;

/* Documentation: Attach to pixel coordinates on the chart. */
const int oc3dAttachCoord = 1;

/* Documentation: Attach to a point in 3D space. */
const int oc3dAttachDataCoord = 2;

/*****************************/
/***** Axis ID Constants *****/
/*****************************/
/* Documentation: Specifies a chart axis. */

/* Documentation: X-axis. */
const int oc3dAxisX = 0;

/* Documentation: Y-axis. */
const int oc3dAxisY = 1;

/* Documentation: Z-axis. */
const int oc3dAxisZ = 2;

/********************************/
/***** Bar Format Constants *****/
/********************************/
/* Documentation: The format in which bars are displayed. */

/* Documentation: Fixed format. */
const int oc3dBarFixed = 0;

/* Documentation: Histogram format. */
const int oc3dBarHistogram = 1;

/*********************************/
/***** Border Type Constants *****/
/*********************************/
/* Documentation: Valid border styles. */

/* Documentation: Border None. */
const int oc3dBorderNone = 0;

/* Documentation: Border 3D Out. */
const int oc3dBorder3DOut = 1;

/* Documentation: Border 3D In. */
const int oc3dBorder3DIn = 2;

/* Documentation: Border Shadow. */
const int oc3dBorderShadow = 3;

/* Documentation: Border Plain. */
const int oc3dBorderPlain = 4;

/* Documentation: Border Etched In. */
const int oc3dBorderEtchedIn = 5;

/* Documentation: Border Etched Out. */
const int oc3dBorderEtchedOut = 6;

/*********************************/
/***** Data Layout Constants *****/
/*********************************/
/* Documentation: Specifies the type of data to be charted. */

/* Documentation: Regular grid data. */
const int oc3dDataGrid = 1;

/* Documentation: Irregular grid data. */
const int oc3dDataIrregularGrid = 2;

/***********************************/
/***** Interpolation Constants *****/
/***********************************/
/* Documentation: Specifies the spline interpolation method to use. */

/* Documentation: Linear spline interpolation. */
const int oc3dInterpolateLinearSpline = 1;

/* Documentation: Cubic spline interpolation. */
const int oc3dInterpolateCubicSpline = 2;

/*********************************/
/***** Legend Type Constants *****/
/*********************************/
/* Documentation: Determines the legend style. */

/* Documentation: Range printed for each zone. */
const int oc3dLegendTypeStepped = 1;

/* Documentation: Level printed at the division between two adjacent zones. */
const int oc3dLegendTypeContinuous = 2;

/**********************************/
/***** Line Pattern Constants *****/
/**********************************/
/* Documentation: Valid line patterns. */

/* Documentation: No Pattern */
const int oc3dLineNone = 1;

/* Documentation: Solid */
const int oc3dLineSolid = 2;

/* Documentation: Long Dash */
const int oc3dLineLongDash = 3;

/* Documentation: Dotted */
const int oc3dLineDotted = 4;

/* Documentation: Short Dash */
const int oc3dLineShortDash = 5;

/* Documentation: Long Short Long Dash */
const int oc3dLineLongShortLongDash = 6;

/* Documentation: Dash Dot */
const int oc3dLineDashDot = 7;

/***************************/
/***** Plane Constants *****/
/***************************/
/* Documentation: Specifies a plane of the chart. */

/* Documentation: The XY-Plane */
const int oc3dXYPlane = 1;

/* Documentation: The XZ-Plane */
const int oc3dXZPlane = 2;

/* Documentation: The YZ-Plane */
const int oc3dYZPlane = 4;

/****************************/
/***** Region Constants *****/
/****************************/
/* Documentation: Specifies a region of a chart. */

/* Documentation: Located in chart area. */
const int oc3dRegionInChartArea = -100;

/* Documentation: Located in legend. */
const int oc3dRegionInLegend = -99;

/* Documentation: Located in header. */
const int oc3dRegionInHeader = -98;

/* Documentation: Located in footer. */
const int oc3dRegionInFooter = -97;

/* Documentation: No particular region. */
const int oc3dRegionNone = -96;

/*********************************/
/***** Stroke Font Constants *****/
/*********************************/
/* Documentation: Specifies a stroke font. */

/* Documentation: Cyrillic Complex */
const int oc3dCyrillicComplex = 0;

/* Documentation: Gothic English */
const int oc3dGothicEnglish = 1;

/* Documentation: Gothic German */
const int oc3dGothicGerman = 2;

/* Documentation: Gothic Italian */
const int oc3dGothicItalian = 3;

/* Documentation: Greek Complex */
const int oc3dGreekComplex = 4;

/* Documentation: Greek Complex Small */
const int oc3dGreekComplexSmall = 5;

/* Documentation: Greek Simplex */
const int oc3dGreekSimplex = 6;

/* Documentation: Italic Complex */
const int oc3dItalicComplex = 7;

/* Documentation: Italic Complex Small */
const int oc3dItalicComplexSmall = 8;

/* Documentation: Italic Triplex */
const int oc3dItalicTriplex = 9;

/* Documentation: Roman Complex */
const int oc3dRomanComplex = 10;

/* Documentation: Roman Complex Small */
const int oc3dRomanComplexSmall = 11;

/* Documentation: Roman Duplex */
const int oc3dRomanDuplex = 12;

/* Documentation: Roman Simplex */
const int oc3dRomanSimplex = 13;

/* Documentation: Roman Triplex */
const int oc3dRomanTriplex = 14;

/* Documentation: Script Complex */
const int oc3dScriptComplex = 15;

/* Documentation: Script Simplex */
const int oc3dScriptSimplex = 16;

/********************************/
/***** Chart Type Constants *****/
/********************************/
/* Documentation: Specifies the chart display type. */

/* Documentation: Surface chart. */
const int oc3dTypeSurface = 0;

/* Documentation: Bar chart. */
const int oc3dTypeBar = 1;

/*********************************/
/***** Zone Method Constants *****/
/*********************************/
/* Documentation: Specifies the method used to fill each zone region. */

/* Documentation: Contour zoning. */
const int oc3dZoneContours = 0;

/* Documentation: Cell zoning. */
const int oc3dZoneCells = 1;

/************************************/
/***** Preview Method Constants *****/
/************************************/
/* Documentation: Specifies how interactive rotations are to be
   presented to the user. */

/* Documentation: Draw outline of plot cube. */
const int oc3dPreviewCube = 0;

/* Documentation: Draw entire chart. */
const int oc3dPreviewFull = 100;

/****************************/
/***** Action Constants *****/
/****************************/
/* Documentation: Specifies a user action. */

/* Documentation: No action. */
const int oc3dActionNone = 0;

/* Documentation: Start any user interaction. */
const int oc3dActionModifyStart = 1;

/* Documentation: Notify application that user interaction has ended. */
const int oc3dActionModifyEnd = 2;

/* Documentation: Cancel a user interaction. */
const int oc3dActionModifyCancel = 3;

/* Documentation: Rotate the chart. */
const int oc3dActionRotate = 4;

/* Documentation: Scale the chart. */
const int oc3dActionScale = 5;

/* Documentation: Translate the chart. */
const int oc3dActionTranslate = 6;

/* Documentation: Start zoom. */
const int oc3dActionZoomStart = 7;

/* Documentation: Update the zoom rubberband. */
const int oc3dActionZoomUpdate = 8;

/* Documentation: End a zoom. */
const int oc3dActionZoomEnd = 9;

/* Documentation: Cancel a zoom in progress. */
const int oc3dActionZoomCancel = 10;

/* Documentation: Undo all scaling and translations. */
const int oc3dActionReset = 11;

/* Documentation: Display property page. */
const int oc3dActionProperties = 12;

/* Documentation: Rotate about X-axis. */
const int oc3dActionRotateXAxis = 100;

/* Documentation: Rotate about Y-axis. */
const int oc3dActionRotateYAxis = 101;

/* Documentation: Rotate about Z-axis. */
const int oc3dActionRotateZAxis = 102;

/* Documentation: Rotate about the eyepoint. */
const int oc3dActionRotateEye = 103;

/* Documentation: Unconstrained Rotation. */
const int oc3dActionRotateFree = 104;

/****************************/
/***** Format Constants *****/
/****************************/
/* Documentation: Specifies the format to use when printing. */

/* Documentation: Bitmap. */
const int oc3dFormatBitmap = 1;

/* Documentation: Metafile. */
const int oc3dFormatMetafile = 2;

/* Documentation: Enhanced Metafile. */
const int oc3dFormatEnhMetafile = 3;

/***************************/
/***** Scale Constants *****/
/***************************/
/* Documentation: Specifies the scaling to use when printing. */

/* Documentation: Same size as actual chart. */
const int oc3dScaleNone = 1;

/* Documentation: Scale to specified width, preserving aspect ratio. */
const int oc3dScaleToWidth = 2;

/* Documentation: Scale to specified height, preserving aspect ratio. */
const int oc3dScaleToHeight = 3;

/* Documentation: Scale to existing window (minimum of height and width),
   preserving aspect ratio. */
const int oc3dScaleToFit = 4;

/* Documentation: Enlarge to size of page. */
const int oc3dScaleToMax = 5;
